View source: R/datasetsverse.R
| DataSetsVerse | R Documentation |
This metapackage provides a curated collection of R packages containing domain-specific datasets. It includes time series data, educational metrics, crime records, medical datasets, and oncology research data.
This function displays a formatted list of the datasets packages included in the DataSetsVerse metapackage and their respective versions.
DataSetsVerse()
DataSetsVerse: A Metapackage for Thematic and Domain-Specific Datasets in R
A Metapackage for Thematic and Domain-Specific Datasets in R.
Invisibly returns the names of the loaded packages.
Maintainer: Renzo Caceres Rossi arenzocaceresrossi@gmail.com
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.